<?php
/**
 * This file is part of the official Amazon Checkout extension for Magento 1.x
 *
 * (c) 2020 creativestyle GmbH. All Rights reserved
 *
 * Distribution of the derivatives reusing, transforming or being built upon
 * this software, is not allowed without explicit written permission granted
 * by creativestyle GmbH
 *
 * @category   Creativestyle
 * @package    Creativestyle_AmazonCheckout
 * @copyright  2021 creativestyle GmbH
 * @author     Marek Stefan <ticket@creativestyle.de>
 */
class Creativestyle_AmazonCheckout_Block_Adminhtml_Debug extends Mage_Adminhtml_Block_Template
{
    /**
     * @var array|null
     */
    protected $_generalData = null;

    /**
     * @var array|null
     */
    protected $_storeViews = null;

    /**
     * @var array|null
     */
    protected $_appliedPatches = null;

    /**
     * Return Amazon Pay debug model instance
     *
     * @return Creativestyle_AmazonCheckout_Model_Debug
     */
    protected function _getDebugModel()
    {
        /** @var Creativestyle_AmazonCheckout_Model_Debug $debugModel */
        $debugModel = Mage::getSingleton('amazonpay/debug');
        return $debugModel;
    }

    public function getDownloadUrl()
    {
        return $this->getUrl('*/*/download');
    }

    public function getAppliedPatches()
    {
        if (null === $this->_appliedPatches) {
            $this->_appliedPatches = $this->_getDebugModel()->getAppliedPatches();
        }
        return $this->_appliedPatches;
    }

    public function getGeneralData()
    {
        if (null === $this->_generalData) {
            $this->_generalData = $this->_getDebugModel()->getGeneralData();
        }
        return $this->_generalData;
    }

    public function getStoreViews()
    {
        if (null === $this->_storeViews) {
            $this->_storeViews = $this->_getDebugModel()->getStoreViews();
        }
        return $this->_storeViews;
    }

    public function getStoreViewKeys()
    {
        $keys = array();
        $storeViews = $this->_getDebugModel()->getStoreViews();
        foreach ($storeViews as $code => $config) {
            $keys = array_merge($keys, array_keys($config));
        }
        return array_unique($keys);
    }

    public function getInstalledExtensions()
    {
        return $this->_getDebugModel()->getInstalledExtensions();
    }
}
