<?php
/**
 * This file is part of the official Amazon Checkout extension for Magento 1.x
 *
 * (c) 2020 creativestyle GmbH. All Rights reserved
 *
 * Distribution of the derivatives reusing, transforming or being built upon
 * this software, is not allowed without explicit written permission granted
 * by creativestyle GmbH
 *
 * @category   Creativestyle
 * @package    Creativestyle_AmazonCheckout
 * @copyright  2020 creativestyle GmbH
 * @author     Marek Stefan <ticket@creativestyle.de>
 */

abstract class Creativestyle_AmazonCheckout_Model_Api_AbstractModel
{
    /**
     * Model field to type map for the fields of non-scalar type
     */
    const FIELD_TYPE_MAP = array();

    /**
     * @param array|null $data
     */
    public function __construct(array $data = null)
    {
        foreach ($data as $key => $value) {
            if (is_array($value) && array_key_exists($key, static::FIELD_TYPE_MAP)) {
                $fieldType = static::FIELD_TYPE_MAP[$key];
                if (is_array($fieldType) && !empty($fieldType)) {
                    $className = $fieldType[0];
                    $this->$key = array_map(function ($item) use ($className) {
                        return new $className($item);
                    }, $value);
                } else {
                    $this->$key = new $fieldType($value);
                }
            } else {
                $this->$key = $value;
            }
        }
    }

    /**
     * @param string $jsonData
     * @return static
     */
    public static function fromJson($jsonData) {
        return new static(json_decode($jsonData, true));
    }
}
